@@ -30,6 +30,7 @@ using System.Diagnostics; //Process
 
 using System.Collections; //ArrayList
 
+
 public class ChronoJump 
 {
 	SplashWindow splashWin;
@@ -68,9 +69,49 @@ public class ChronoJump
 		System.Console.SetOut(sw);
 		System.Console.SetError(sw);
 		sw.AutoFlush = true;
-*/
+		*/
 
-		baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory,"../../");
+		
+		var envPath = Environment.GetEnvironmentVariable ("PATH");
+		var rBinPath = "";
+		baseDirectory = Util.GetPrefixDir();
+		if(UtilAll.IsWindows()) {
+			//Environment.SetEnvironmentVariable ("R_HOME", RelativeToPrefix ("library"));
+			//rBinPath = RelativeToPrefix ("lib");
+			//rBinPath = RelativeToPrefix ("library");
+			//var rPath = System.Environment.Is64BitProcess ? @"C:\Program Files\R\R-3.0.2\bin\x64" : @"C:\Program Files\R\R-3.0.2\bin\i386";
+			string x64 = "bin" + System.IO.Path.DirectorySeparatorChar + "x64";
+			string i386 = "bin" + System.IO.Path.DirectorySeparatorChar + "i386";
+			var rPath = System.Environment.Is64BitProcess ? 
+				System.IO.Path.Combine(baseDirectory, x64) : System.IO.Path.Combine(baseDirectory, i386);
+
+			if (Directory.Exists(rPath) == false) {
+				throw new DirectoryNotFoundException(string.Format("Could not found the specified path to the directory containing R.dll: {0}", rPath));
+				Log.WriteLine("Could not found the specified path to the directory containing R.dll: " + rPath);
+			}
+
+			var newPath = string.Format("{0}{1}{2}", rPath, System.IO.Path.PathSeparator, envPath);
+			Log.WriteLine("newPath:" + newPath);
+		
+			System.Environment.SetEnvironmentVariable("PATH", newPath);
+			Log.WriteLine("path:" + System.Environment.GetEnvironmentVariable("PATH"));
+			
+			//use this because we don't want to look at the registry
+			//we don't want to force user to install R
+			Environment.SetEnvironmentVariable ("R_HOME", baseDirectory);
+			Log.WriteLine("R_HOME:" + baseDirectory);
+		} else {
+			rBinPath = @"/usr/lib/R/lib";
+			Environment.SetEnvironmentVariable ("R_HOME", @"/usr/lib/R");
+			Environment.SetEnvironmentVariable("PATH", envPath + Path.PathSeparator + rBinPath);
+		}
+		
+		
+		Log.WriteLine("baseDir0:" + System.AppDomain.CurrentDomain.BaseDirectory);
+		Log.WriteLine("baseDir1:" + baseDirectory);
+		Log.WriteLine("envPath+rBinPath:" + envPath + Path.PathSeparator + rBinPath);
+		
+				
 		if(UtilAll.IsWindows())
 			Environment.SetEnvironmentVariable("GST_PLUGIN_PATH",RelativeToPrefix("lib\\gstreamer-0.10"));
 
@@ -87,7 +128,8 @@ public class ChronoJump
 			createBlankDBServer();
 			Environment.Exit(1);
 		}
-		
+
+
 		Catalog.Init("chronojump",System.IO.Path.Combine(Util.GetPrefixDir(),"share/locale"));
 					
 			
@@ -137,6 +179,7 @@ public class ChronoJump
 		if(crashedBefore) {
 			if(chronojumpIsExecutingNTimes()) {
 				quitNow = true;
+				Log.WriteLine("\n\nChronojump is already running.\n");
 				Application.Quit();
 				return;
 			}
@@ -152,7 +195,7 @@ public class ChronoJump
 		//to store user videos and photos
 		Util.CreateMultimediaDirsIfNeeded();
 		//to store encoder data and graphs
-		Util.CreateEncoderDirIfNeeded();
+		UtilEncoder.CreateEncoderDirIfNeeded();
 
 //TODO: create encoder session dirs when load or create a session, or when use encoder with button capture_from_encoder
 //TODO: when a session is deleted, encoder data has to be deleted, also multimedia videos, I suppose. Show message to user warning about it
@@ -418,7 +461,9 @@ Console.WriteLine("--6--");
 			ErrorWindow errorWin;
 			if(chronojumpHasToExit) {
 				messageToShowOnBoot += "\n<b>" + string.Format(Catalog.GetString("Chronojump will exit now.")) + "</b>\n";
+
 				errorWin = ErrorWindow.Show(messageToShowOnBoot);
+				errorWin.Show_button_open_database_folder();
 				errorWin.Button_accept.Clicked += new EventHandler(on_message_boot_accepted_quit);
 			} else { 
 				errorWin = ErrorWindow.Show(messageToShowOnBoot);
