@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -28,23 +28,47 @@ public class Constants
 	//the strings created by Catalog cannot be const
 	
 	//public static string ReadmeTranslators = Catalog.GetString("Translator, there's a glossary that will help you in Chronojump translation:\n http://git.gnome.org/browse/chronojump/plain/glossary/chronojump_glossary_for_translators.html");
-
-	public static string [] Authors = {
-		"Xavier de Blas Foix (xaviblas@gmail.com)\n" + Catalog.GetString("Project leader and main developer."), 
-		"Juan Gonzalez Gómez (http://www.iearobotics.com)\n" + Catalog.GetString("Skypic, Chronopic, connection between hardware and software."), 
-		"Juan Fernando Pardo (juanfer@juanfer.com.ar)\n" + Catalog.GetString("Chronopic2 creation, Chronojump tester."), 
-		"Ricardo Gómez González (http://www.iearobotics.com)\n" + Catalog.GetString("Chronopic3 industrial prototype."),
-		"Sharad Shankar (http://www.logicbrick.com)\n" + Catalog.GetString("OpenCV Detection of knee angle."), 
-		"Onkar Nath Mishra (http://www.logicbrick.com)\n" + Catalog.GetString("OpenCV Detection of knee angle."),
-		"Andoni Morales Alastruey (http://ylatuya.es)\n" + Catalog.GetString("Installation support: Autotools, packaging, bundle."), 
-		"Carlos J. Gil Bellosta (http://www.datanalytics.com)\n" + Catalog.GetString("Statistics support."),
-		"Teng Wei Hua (wadedang@gmail.com)\n" + Catalog.GetString("Translation of Firmware to C.") + "\n" +
-			Catalog.GetString("New firmware features.") + " " + Catalog.GetString("Encoder hardware layer.") 
+	
+	public static string [] AuthorsCEO = {
+		"Xavier de Blas Foix (info@chronojump.org)\n",
+		"Josep Ma Padullés (jmpadulles@gmail.com)"	
 	};
+	public static string [] AuthorsSoftware = {
+		"Xavier de Blas Foix (xaviblas@gmail.com)\n\t" + 
+			Catalog.GetString("Main developer.") + "\n",
+		"Andoni Morales Alastruey (http://ylatuya.es)\n\t" + 
+			Catalog.GetString("Installation support: Autotools, packaging, bundle.")
+	};
+	public static string [] AuthorsChronopic = {
+		"Teng Wei Hua (wadedang@gmail.com)\n\t" + Catalog.GetString("Translation of Firmware to C.") + "\n\t" +
+			Catalog.GetString("New firmware features.") + " " + Catalog.GetString("Encoder hardware layer.") + "\n",
+		"Juan Gonzalez Gómez (http://www.iearobotics.com)\n\t" + Catalog.GetString("Skypic, Chronopic, connection between hardware and software.") + "\n", 
+		"Ricardo Gómez González (http://www.iearobotics.com)\n\t" + Catalog.GetString("Chronopic3 industrial prototype.") + "\n",
+		"Juan Fernando Pardo (juanfer@juanfer.com.ar)\n\t" + "Chronopic2."
+	};
+	public static string [] AuthorsDevices = {
+		"Josep Ma Padullés (jmpadulles@gmail.com)\n",
+		"Anna Padullés (hardware@chronojump.org)\n",
+		"Xavier Padullés (testing@chronojump.org)\n",
+		"Teng Wei Hua (wadedang@gmail.com)\n",
+		"Xavier de Blas Foix (info@chronojump.org)"
+	};
+	public static string [] AuthorsMath = {
+		"Carlos J. Gil Bellosta (http://www.datanalytics.com)\n",
+		"Aleix Ruiz de Villa (aleixrvr@gmail.com)\n",
+		"Xavier Padullés (testing@chronojump.org)"
+	};
+	public static string [] AuthorsOpenCV = {
+		"Sharad Shankar (http://www.logicbrick.com)\n", 
+		"Onkar Nath Mishra (http://www.logicbrick.com)\n"
+	};
+
 	public static string [] Documenters = {
-		"Xavier de Blas Foix (xaviblas@gmail.com)\n\n",
-		"Helena Olsson (hjolsson@gmail.com)\n",
-		"(" + Catalog.GetString("Chronojump Manual English translation") + ")"
+		"Xavier de Blas Foix (xaviblas@gmail.com)\n\t" +
+			Catalog.GetString("Chronojump Manual author."),
+		"Helena Olsson (hjolsson@gmail.com)\n\t" +
+			Catalog.GetString("Chronojump Manual English translation."),
+		"Xavier Padullés (testing@chronojump.org)",
 	};
 	
 	public static string ChronojumpWebsite = "http://www.chronojump.org";
@@ -174,7 +198,8 @@ public class Constants
 	public static string TakeOffWeightName = "TakeOffWeight"; //translate (take off?)
 
 
-	public static string SpreadsheetString = "\n\n" + Catalog.GetString("When import from your spreadsheet (OpenOffice, R, MS Excel, ...)\nremember the separator character is semicolon <b>;</b>, or comma <b>,</b>.");
+	public static string SpreadsheetString = "\n\n" + Catalog.GetString("When import from your spreadsheet (OpenOffice, R, MS Excel, ...)\nremember the separator character is semicolon <b>;</b>, or comma <b>,</b>.") + 
+			"\n\n" + Catalog.GetString("This can be changed on preferences.");
 
 /*	OLD, check this
 	public static string PotencyLewisCMJFormula = Catalog.GetString("Peak Power")+ " CMJ (Lewis) " +
@@ -342,6 +367,7 @@ public class Constants
 	public static string FileNameZoomInWithTextIcon = "gtk-zoom-in-with-text.png";
 	public static string FileNameNew1 = "gtk-new-1.png";
 	public static string FileNameNewPlus = "gtk-new-plus.png";
+	public static string FileNameOpen = "gtk-open.png";
 	public static string FileNameOpen1 = "gtk-open-1.png";
 	public static string FileNameOpenPlus = "gtk-open-plus.png";
 
@@ -502,6 +528,8 @@ public class Constants
 		Catalog.GetString("Check for new version"),	//5
 		Catalog.GetString("Preparing main Window"),	//6
 	};
+	
+	public static string DatabaseNotFound = Catalog.GetString("Error. Cannot find database");
 
 	public static string ChronopicDefaultPortWindows = "COM?";
 	public static string ChronopicDefaultPortLinux = "/dev/ttyUSB?";
@@ -540,7 +568,8 @@ public class Constants
 
 	//heightmetric contains 2 spins
 	public enum GenericWindowShow {
-		ENTRY, ENTRY2, ENTRY3, SPININT, SPINDOUBLE, HBOXSPINDOUBLE2, HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
+		ENTRY, ENTRY2, ENTRY3, SPININT, SPININT2, SPININT3, SPINDOUBLE, HBOXSPINDOUBLE2, 
+		HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
 	}
 	
 	public const string PrefVersionAvailable = "versionAvailable";
@@ -585,6 +614,8 @@ public class Constants
 	public static string EncoderScriptCaptureLinux = "pyserial_pyper.py";
 	public static string EncoderScriptCaptureWindows = "pyserial_pyper_windows.exe";
 	public static string EncoderScriptGraph = "graph.R";
+	public static string EncoderScriptInertiaMomentum = "inertia-momentum.R";
+	public static string EncoderScriptUtilR = "util.R";
 	//no longer used:
 	//public static string EncoderScriptGraphCall = 
 		//"/home/xavier/informatica/progs_meus/chronojump/chronojump/encoder/call_graph.py";
@@ -601,11 +632,79 @@ public class Constants
 	//if this name changes, change it in encoder/graph.R
 	public static string EncoderGraphInputMulti = "chronojump-encoder-graph-input-multi.csv"; 
 
+	public static string Concentric = "Concentric";
+	public static string EccentricConcentric = "Eccentric-concentric";
+	//public static string ConcentricEccentric = "Concentric-eccentric";
+
 	public enum EncoderCheckFileOp { ANALYZE_EXPORT_ALL_CURVES, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_TABLE}
+
+	public static double EncoderErrorCode = -1;
+	
+	//three encoder types
+	public static string FileNameEncoderTypeLinear = "encoder-linear.png";
+	public static string FileNameEncoderTypeRotaryFriction = "encoder-rotary-friction.png";
+	public static string FileNameEncoderTypeRotaryAxis = "encoder-rotary-axis.png";
+	
+	//encoder configurations
+	//linear
+	public static string FileNameEncoderLinearFreeWeight = "encoder-linear-free-weight.png";
+	public static string FileNameEncoderLinearFreeWeightInv = "encoder-linear-free-weight-inv.png";
+	public static string FileNameEncoderLinearInertial = "encoder-linear-inertial.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson1 = "encoder-linear-on-person-weighted-moving-pulley1.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson1Inv = "encoder-linear-inv-on-person-weighted-moving-pulley1.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson2 = "encoder-linear-on-person-weighted-moving-pulley2.png";
+	public static string FileNameEncoderWeightedMovPulleyOnPerson2Inv = "encoder-linear-inv-on-person-weighted-moving-pulley2.png";
+	public static string FileNameEncoderWeightedMovPulleyOnLinearEncoder = "encoder-linear-on-weighted-moving-pulley.png";
+	public static string FileNameEncoderLinearOnPlane = "encoder-linear-inclined-plane.png";	
+	public static string FileNameEncoderLinearOnPlaneWeightDiffAngle = "encoder-linear-inclined-plane-weight-diff-angle.png";	
+
+	//rotary friction
+	public static string FileNameEncoderFrictionSide = "encoder-rotary-friction-pulley.png";
+	public static string FileNameEncoderFrictionAxis = "encoder-rotary-friction-pulley-axis.png";
+	public static string FileNameEncoderFrictionSideInertial = "encoder-rotary-friction-side-inertial.png";
+	public static string FileNameEncoderFrictionAxisInertial = "encoder-rotary-friction-axis-inertial.png";
+	public static string FileNameEncoderFrictionWithMovPulley = "encoder-rotary-friction-on-fixed-pulley-with-weighted-moving-pulley.png";
+
+	//rotary axis
+	public static string FileNameEncoderRotaryAxisOnAxis = "encoder-rotary-axis-pulley-axis.png";
+	public static string FileNameEncoderAxisInertial = "encoder-rotary-axis-inertial.png";
+	public static string FileNameEncoderAxisWithMovPulley = "encoder-rotary-axis-on-fixed-pulley-with-weighted-moving-pulley.png";
+	
+	public static string FileNameEncoderCalculeIM = "encoder-calcule-im.png";	
+
+	public enum EncoderConfigurationNames { //this names are used on graph.R change there also if needed
+		LINEAR, LINEARINVERTED, LINEARINERTIAL, 
+		WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
+		WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
+		WEIGHTEDMOVPULLEYONLINEARENCODER, 
+		LINEARONPLANE, LINEARONPLANEWEIGHTDIFFANGLE, 
+		ROTARYFRICTIONSIDE, ROTARYFRICTIONAXIS,				//friction
+		ROTARYFRICTIONSIDEINERTIAL, ROTARYFRICTIONAXISINERTIAL,		//friction
+		WEIGHTEDMOVPULLEYROTARYFRICTION,				//friction
+		ROTARYAXIS, ROTARYAXISINERTIAL, WEIGHTEDMOVPULLEYROTARYAXIS	//axis
+	}
+
+	public static string DefaultEncoderConfigurationCode = "Linear - barbell";
+	
+	public enum EncoderType {
+		LINEAR, ROTARYFRICTION, ROTARYAXIS
+	}	
+
+	public static string MeanSpeed = "Mean speed";
+	public static string MaxSpeed = "Max speed";
+	public static string MeanPower = "Mean power";
+	public static string PeakPower = "Peak power";
+		
 	public enum Encoder1RMMethod { NONWEIGHTED, WEIGHTED, WEIGHTED2, WEIGHTED3 }
 	public enum ContextMenu { NONE, EDITDELETE, DELETE }
 
 	public enum DoubleContact {
 		FIRST, AVERAGE, LAST
 	}
+	
+	public enum MassType {
+		BODY, EXTRA, DISPLACED
+	}	
+	
+	public enum Status { ERROR, UNSTARTED, OK}	
 }
