@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -64,7 +64,7 @@ public class JumpTypeAddWindow
 
 	JumpTypeAddWindow (Gtk.Window parent, bool simple) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jump_type_add", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jump_type_add", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent =  parent;
 		
@@ -124,7 +124,7 @@ public class JumpTypeAddWindow
 	void on_button_accept_clicked (object o, EventArgs args)
 	{
 		//check if this jump type exists, and check it's name is not AllJumpsName
-		bool jumpTypeExists = Sqlite.Exists (Constants.JumpTypeTable, Util.RemoveTildeAndColonAndDot(entry_name.Text));
+		bool jumpTypeExists = Sqlite.Exists (false, Constants.JumpTypeTable, Util.RemoveTildeAndColonAndDot(entry_name.Text));
 		if(Util.RemoveTildeAndColonAndDot(entry_name.Text) == Constants.AllJumpsName) {
 			jumpTypeExists = true;
 		}
