@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -60,15 +60,16 @@ public class PreferencesWindow {
 	[Widget] Gtk.RadioButton radio_weight_kg;
 	
 	[Widget] Gtk.CheckButton checkbutton_encoder_propulsive;
-	[Widget] Gtk.SpinButton spin_encoder_smooth_ecc_con;
 	[Widget] Gtk.SpinButton spin_encoder_smooth_con;
-	[Widget] Gtk.Label label_encoder_ecc_con;
 	[Widget] Gtk.Label label_encoder_con;
 			
 	[Widget] Gtk.RadioButton radio_encoder_1RM_nonweighted;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted2;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted3;
+			
+	[Widget] Gtk.RadioButton radio_export_latin;
+	[Widget] Gtk.RadioButton radio_export_non_latin;
 
 //	[Widget] Gtk.Box hbox_language_row;
 //	[Widget] Gtk.Box hbox_combo_language;
@@ -88,7 +89,7 @@ public class PreferencesWindow {
 
 	PreferencesWindow () {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "preferences", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "preferences", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
@@ -106,8 +107,9 @@ public class PreferencesWindow {
 	static public PreferencesWindow Show (int digitsNumber, bool showHeight, bool showPower,  
 			bool showInitialSpeed, bool showAngle, bool showQIndex, bool showDjIndex,
 			bool askDeletion, bool weightStatsPercent, bool heightPreferred, bool metersSecondsPreferred, 
-			string language, bool encoderPropulsive, double encoderSmoothEccCon, double encoderSmoothCon,
-			string [] videoDevices, int videoDeviceNum, string encoder1RMMethod)
+			string language, bool encoderPropulsive, double encoderSmoothCon,
+			string [] videoDevices, int videoDeviceNum, string encoder1RMMethod,
+			string CSVExportDecimalSeparator)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
@@ -185,10 +187,16 @@ public class PreferencesWindow {
 			PreferencesWindowBox.radio_speed_ms.Active = true; 
 		else 
 			PreferencesWindowBox.radio_speed_km.Active = true; 
+
+
+		if(CSVExportDecimalSeparator == "COMMA")
+			PreferencesWindowBox.radio_export_latin.Active = true; 
+		else
+			PreferencesWindowBox.radio_export_non_latin.Active = true; 
+
 	
 		//encoder	
 		PreferencesWindowBox.checkbutton_encoder_propulsive.Active = encoderPropulsive;
-		PreferencesWindowBox.spin_encoder_smooth_ecc_con.Value = encoderSmoothEccCon;
 		PreferencesWindowBox.spin_encoder_smooth_con.Value = encoderSmoothCon;
 
 		if(encoder1RMMethod == Constants.Encoder1RMMethod.NONWEIGHTED.ToString())
@@ -217,7 +225,6 @@ public class PreferencesWindow {
 		*/
 
 		//done here and not in glade to be shown with the decimal point of user language	
-		PreferencesWindowBox.label_encoder_ecc_con.Text = (0.6).ToString();
 		PreferencesWindowBox.label_encoder_con.Text = (0.7).ToString();
 
 		PreferencesWindowBox.preferences.Show ();
@@ -318,7 +325,7 @@ public class PreferencesWindow {
 		else if(file2.Exists)
 			System.Diagnostics.Process.Start(Util.GetDatabaseTempDir()); 
 		else
-			new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Error. Cannot find database."));
+			new DialogMessage(Constants.MessageTypes.WARNING, Constants.DatabaseNotFound);
 	}
 	
 	string fileDB;
@@ -424,11 +431,14 @@ public class PreferencesWindow {
 		
 		SqlitePreferences.Update("encoderPropulsive", 
 				PreferencesWindowBox.checkbutton_encoder_propulsive.Active.ToString(), true);
-		SqlitePreferences.Update("encoderSmoothEccCon", Util.ConvertToPoint( 
-				(double) PreferencesWindowBox.spin_encoder_smooth_ecc_con.Value), true);
 		SqlitePreferences.Update("encoderSmoothCon", Util.ConvertToPoint( 
 				(double) PreferencesWindowBox.spin_encoder_smooth_con.Value), true);
 		SqlitePreferences.Update("videoDevice", UtilGtk.ComboGetActivePos(combo_camera).ToString(), true);
+		
+		if(PreferencesWindowBox.radio_export_latin.Active)
+			SqlitePreferences.Update("CSVExportDecimalSeparator","COMMA", true); 
+		else
+			SqlitePreferences.Update("CSVExportDecimalSeparator","POINT", true); 
 	
 		string encoder1RMMethod = "";	
 		if(PreferencesWindowBox.radio_encoder_1RM_nonweighted.Active)
