@@ -53,15 +53,63 @@ public class ExecutingGraphData
 }	
 
 public class PrepareEventGraphJumpSimple {
+	//sql data of previous jumps to plot graph and show stats at bottom
+	public string [] jumpsAtSQL;
+	public double tvPersonAVGAtSQL;
+	public double tvSessionAVGAtSQL;
+	public double heightPersonAVGAtSQL;
+	public double heightSessionAVGAtSQL;
+	public double tcPersonAVGAtSQL;
+	public double tcSessionAVGAtSQL;
+
+	//current data
 	public double tv;
 	public double tc;
 
 	public PrepareEventGraphJumpSimple() {
 	}
 
-	public PrepareEventGraphJumpSimple(double tv, double tc) {
+	public PrepareEventGraphJumpSimple(double tv, double tc, int sessionID, int personID, string table, string type) 
+	{
+
+		Sqlite.Open();
+
+		//select data from SQL to update graph	
+		jumpsAtSQL = SqliteJump.SelectJumps(true, sessionID, personID, "", type);
+
+		tvPersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+				true, sessionID, personID, 
+				table, type, "TV");
+		tvSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+				true, sessionID, -1, table, type, "TV");
+
+		//need to calculate height also, because:
+		//it's different to have mean of tv and then calculate height of that mean
+		//than have every height and then calculate the mean
+
+		heightPersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+				true, sessionID, personID, 
+				table, type, "100*4.9*(TV/2)*(TV/2)");
+		heightSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+				true, sessionID, -1, table, type, "100*4.9*(TV/2)*(TV/2)");
+
+
+		tcPersonAVGAtSQL = 0; 
+		tcSessionAVGAtSQL = 0; 
+		if(tc > 0) {
+			tcPersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+					true, sessionID, personID, 
+					table, type, "TC");
+			tcSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+					true, sessionID, -1, table, type, "TC");
+		}
+
+		//end of select data from SQL to update graph	
+			
 		this.tv = tv;
 		this.tc = tc;
+		
+		Sqlite.Close();
 	}
 
 	~PrepareEventGraphJumpSimple() {}
@@ -87,15 +135,44 @@ public class PrepareEventGraphJumpReactive {
 }
 
 public class PrepareEventGraphRunSimple {
+	//sql data of previous runs to plot graph and show stats at bottom
+	public string [] runsAtSQL;
+	public double timePersonAVGAtSQL;
+	public double timeSessionAVGAtSQL;
+	public double speedPersonAVGAtSQL;
+	public double speedSessionAVGAtSQL;
+	
 	public double time;
 	public double speed;
 
 	public PrepareEventGraphRunSimple() {
 	}
 
-	public PrepareEventGraphRunSimple(double time, double speed) {
+	public PrepareEventGraphRunSimple(double time, double speed, int sessionID, int personID, string table, string type) 
+	{
+		Sqlite.Open();
+		
+		//obtain data
+		runsAtSQL = SqliteRun.SelectRuns(true, sessionID, personID, type);
+
+		timePersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, personID, table, type, "time");
+		timeSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, -1, table, type, "time");
+
+		//distancePersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, personID, table, type, "distance");
+		//distanceSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, -1, table, type, "distance");
+		//better to know speed like:
+		//SELECT AVG(distance/time) from run; than 
+		//SELECT AVG(distance) / SELECT AVG(time) 
+		//first is ok, because is the speed AVG
+		//2nd is not good because it tries to do an AVG of all distances and times
+		speedPersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, personID, table, type, "distance/time");
+		speedSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, -1, table, type, "distance/time");
+		
+		
 		this.time = time;
 		this.speed = speed;
+		
+		Sqlite.Close();
 	}
 
 	~PrepareEventGraphRunSimple() {}
@@ -138,12 +215,30 @@ public class PrepareEventGraphPulse {
 }
 
 public class PrepareEventGraphReactionTime {
+	//sql data of previous rts to plot graph and show stats at bottom
+	public string [] rtsAtSQL;
+	public double timePersonAVGAtSQL;
+	public double timeSessionAVGAtSQL;
+
 	public double time;
 
 	public PrepareEventGraphReactionTime() {
 	}
 
-	public PrepareEventGraphReactionTime(double time) {
+	public PrepareEventGraphReactionTime(double time, int sessionID, int personID, string table, string type) 
+	{
+		Sqlite.Open();
+
+		//obtain data
+		rtsAtSQL = SqliteReactionTime.SelectReactionTimes(true, sessionID, personID);
+
+		timePersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+				true, sessionID, personID, table, type, "time");
+		timeSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(
+				true, sessionID, -1, table, type, "time");
+		
+		Sqlite.Close();
+	
 		this.time = time;
 	}
 
