@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -25,6 +25,8 @@ using System.Collections; //ArrayList
 using Mono.Data.Sqlite;
 using System.Diagnostics; 	//for launching other process
 
+using Mono.Unix;
+
 
 class Sqlite
 {
@@ -72,7 +74,7 @@ class Sqlite
 	 * Important, change this if there's any update to database
 	 * Important2: if database version get numbers higher than 1, check if the comparisons with currentVersion works ok
 	 */
-	static string lastChronojumpDatabaseVersion = "0.95";
+	static string lastChronojumpDatabaseVersion = "1.04";
 
 	public Sqlite() {
 	}
@@ -1208,7 +1210,8 @@ class Sqlite
 			if(currentVersion == "0.88") {
 				dbcon.Open();
 	
-				SqliteEncoder.InsertExercise(true, "Free", 0, "", "", "");
+				SqliteEncoder.addEncoderFreeExercise();
+				
 				Log.WriteLine("Added encoder exercise: Free");
 				
 				SqlitePreferences.Update ("databaseVersion", "0.89", true); 
@@ -1254,8 +1257,8 @@ class Sqlite
 			if(currentVersion == "0.92") {
 				dbcon.Open();
 				
-				SqliteEncoder.UpdateExercise(true, "Bench press", 0, "weight bar", "","0.185");	
-				SqliteEncoder.UpdateExercise(true, "Squat", 100, "weight bar", "","0.31");	
+				SqliteEncoder.UpdateExercise(true, "Bench press", 0, "weight bar", "","0.185");
+				SqliteEncoder.UpdateExercise(true, "Squat", 100, "weight bar", "","0.31");
 				Log.WriteLine("Added speed1RM on encoder exercise");
 				
 				SqlitePreferences.Update ("databaseVersion", "0.93", true); 
@@ -1286,6 +1289,190 @@ class Sqlite
 
 				currentVersion = "0.95";
 			}
+			if(currentVersion == "0.95") {
+				dbcon.Open();
+				
+				Update(true, Constants.EncoderTable, "future3", "", Constants.EncoderConfigurationNames.LINEAR.ToString(), 
+						"signalOrCurve", "signal");
+				Update(true, Constants.EncoderTable, "future3", "0", Constants.EncoderConfigurationNames.LINEAR.ToString(), 
+						"signalOrCurve", "signal");
+				Update(true, Constants.EncoderTable, "future3", "1", Constants.EncoderConfigurationNames.LINEARINVERTED.ToString(),
+						"signalOrCurve", "signal");
+
+				Log.WriteLine("Encoder signal future3 three modes");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.96", true); 
+				dbcon.Close();
+
+				currentVersion = "0.96";
+			}
+			if(currentVersion == "0.96") {
+				dbcon.Open();
+				
+				SqlitePreferences.Insert ("inertialmomentum", "0.01");
+				Log.WriteLine("Added inertialmomentum in preferences");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.97", true); 
+				dbcon.Close();
+
+				currentVersion = "0.97";
+			}
+			if(currentVersion == "0.97") {
+				dbcon.Open();
+				
+				Update(true, Constants.EncoderTable, "laterality", "both", "RL", "", "");
+				Update(true, Constants.EncoderTable, "laterality", "Both", "RL", "", "");
+				Update(true, Constants.EncoderTable, "laterality", Catalog.GetString("Both"), "RL", "", "");
+				Update(true, Constants.EncoderTable, "laterality", "right", "R", "", "");
+				Update(true, Constants.EncoderTable, "laterality", "Right", "R", "", "");
+				Update(true, Constants.EncoderTable, "laterality", Catalog.GetString("Right"), "R", "", "");
+				Update(true, Constants.EncoderTable, "laterality", "left", "L", "", "");
+				Update(true, Constants.EncoderTable, "laterality", "Left", "L", "", "");
+				Update(true, Constants.EncoderTable, "laterality", Catalog.GetString("Left"), "L", "", "");
+				Log.WriteLine("Fixed encoder laterality");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.98", true); 
+				dbcon.Close();
+
+				currentVersion = "0.98";
+			}
+			if(currentVersion == "0.98") {
+				dbcon.Open();
+		
+				ArrayList array = SqliteOldConvert.EncoderSelect098(true,-1,-1,-1,"all",false);
+				
+				conversionRateTotal = array.Count;
+				
+				dropTable(Constants.EncoderTable);
+				SqliteEncoder.createTableEncoder();
+			
+				int count = 1;	
+				foreach( EncoderSQL098 es in array) {
+					conversionRate = count;
+				
+					//do not use SqliteEncoder.Insert because that method maybe changes in the future,
+					//and here we need to do a conversion that works from 0.98 to 0.99
+					dbcmd.CommandText = "INSERT INTO " + Constants.EncoderTable +  
+						" (uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, " + 
+						"signalOrCurve, filename, url, time, minHeight, smooth, description, status, " +
+						"videoURL, mode, inertiaMomentum, diameter, future1, future2, future3)" +
+						" VALUES (" + es.uniqueID + ", " +
+						es.personID + ", " + es.sessionID + ", " +
+						es.exerciseID + ", '" + es.eccon + "', '" +
+						es.laterality + "', '" + es.extraWeight + "', '" +
+						es.signalOrCurve + "', '" + es.filename + "', '" +
+						es.url + "', " + es.time + ", " + es.minHeight + ", " +
+						Util.ConvertToPoint(es.smooth) + ", '" + es.description + "', '" +
+						es.future1 + "', '" + es.future2 + "', 'LINEAR', " + //status, videoURL, mode
+						"0, 0, '', '', '')"; //inertiaMomentum, diameter, future1, 2, 3
+					Log.WriteLine(dbcmd.CommandText.ToString());
+					dbcmd.ExecuteNonQuery();
+					count ++;
+				}	
+
+				conversionRate = count;
+				Log.WriteLine("Encoder table improved");
+				SqlitePreferences.Update ("databaseVersion", "0.99", true); 
+				dbcon.Close();
+
+				currentVersion = "0.99";
+			}
+			if(currentVersion == "0.99") {
+				dbcon.Open();
+
+				SqliteEncoder.putEncoderExerciseAnglesAt90();
+				SqliteEncoder.addEncoderJumpExercise();
+				SqliteEncoder.addEncoderInclinatedExercises();
+
+				Log.WriteLine("Added Free and inclinatedExercises");
+				SqlitePreferences.Update ("databaseVersion", "1.00", true); 
+				dbcon.Close();
+
+				currentVersion = "1.00";
+			}
+			if(currentVersion == "1.00") {
+				dbcon.Open();
+			
+				SqlitePreferences.Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale());
+
+				Log.WriteLine("Added export to CSV configuration on preferences");
+				SqlitePreferences.Update ("databaseVersion", "1.01", true); 
+				dbcon.Close();
+
+				currentVersion = "1.01";
+			}
+			if(currentVersion == "1.01") {
+				dbcon.Open();
+			
+				RunType type = new RunType("Agility-T-Test");
+				SqliteRunType.Insert(type, Constants.RunTypeTable, true);
+				type = new RunType("Agility-3L3R");
+				SqliteRunIntervalType.Insert(type, Constants.RunIntervalTypeTable, true);
+
+				Log.WriteLine("Added Agility Tests: Agility-T-Test, Agility-3l3R");
+				SqlitePreferences.Update ("databaseVersion", "1.02", true); 
+				dbcon.Close();
+
+				currentVersion = "1.02";
+			}
+			if(currentVersion == "1.02") {
+				dbcon.Open();
+		
+				DeleteFromName(true, Constants.EncoderExerciseTable, "Inclinated plane Custom");
+				SqliteEncoder.removeEncoderExerciseAngles();
+
+				Log.WriteLine("Updated encoder exercise, angle is now on encoder configuration");
+				SqlitePreferences.Update ("databaseVersion", "1.03", true); 
+				dbcon.Close();
+
+				currentVersion = "1.03";
+			}
+			if(currentVersion == "1.03") {
+				dbcon.Open();
+		
+				ArrayList array = SqliteOldConvert.EncoderSelect103(true,-1,-1,-1,"all",false);
+				
+				conversionRateTotal = array.Count;
+				
+				dropTable(Constants.EncoderTable);
+				SqliteEncoder.createTableEncoder();
+				
+				//in this conversion put this as default for all SQL rows
+				EncoderConfiguration econf = new EncoderConfiguration();
+			
+				int count = 1;	
+				foreach(EncoderSQL103 es in array) {
+					conversionRate = count;
+				
+					//do not use SqliteEncoder.Insert because that method maybe changes in the future,
+					//and here we need to do a conversion that works from 1.03 to 1.04
+					dbcmd.CommandText = "INSERT INTO " + Constants.EncoderTable +  
+						" (uniqueID, personID, sessionID, exerciseID, eccon, laterality, extraWeight, " + 
+						"signalOrCurve, filename, url, time, minHeight, description, status, " +
+						"videoURL, encoderConfiguration, future1, future2, future3)" +
+						" VALUES (" + es.uniqueID + ", " +
+						es.personID + ", " + es.sessionID + ", " +
+						es.exerciseID + ", '" + es.eccon + "', '" +
+						es.laterality + "', '" + es.extraWeight + "', '" +
+						es.signalOrCurve + "', '" + es.filename + "', '" +
+						es.url + "', " + es.time + ", " + es.minHeight + ", '" + es.description + "', '" + 
+						es.status + "', '" + es.videoURL + "', '" + 
+						econf.ToString(":", true) + "', '" + //in this conversion put this as default for all SQL rows
+						es.future1 + "', '" + es.future2 + "', '" + es.future3 + "')";
+					Log.WriteLine(dbcmd.CommandText.ToString());
+					dbcmd.ExecuteNonQuery();
+					count ++;
+				}	
+
+				conversionRate = count;
+				Log.WriteLine("Encoder table improved");
+				SqlitePreferences.Update ("databaseVersion", "1.04", true); 
+				dbcon.Close();
+
+				currentVersion = "1.04";
+			}
+
+				
 		}
 
 		//if changes are made here, remember to change also in CreateTables()
@@ -1425,6 +1612,15 @@ class Sqlite
 		SqliteCountry.initialize();
 		
 		//changes [from - to - desc]
+		//1.03 - 1-04 Converted DB to 1.04 Encoder table improved
+		//1.02 - 1-03 Converted DB to 1.03 Updated encoder exercise, angle is now on encoder configuration
+		//1.01 - 1-02 Converted DB to 1.02 Added Agility Tests: Agility-T-Test, Agility-3L3R
+		//1.00 - 1.01 Converted DB to 1.01 Added export to CSV configuration on preferences
+		//0.99 - 1.00 Converted DB to 1.00 Encoder added Free and Inclinated Exercises
+		//0.98 - 0.99 Converted DB to 0.99 Encoder table improved 
+		//0.97 - 0.98 Converted DB to 0.98 Fixed encoder laterality
+		//0.96 - 0.97 Converted DB to 0.97 Added inertialmomentum in preferences
+		//0.95 - 0.96 Converted DB to 0.96 Encoder signal future3 three modes
 		//0.94 - 0.95 Converted DB to 0.95 Added encoder1RMMethod
 		//0.93 - 0.94 Converted DB to 0.94 Added encoder1RM table
 		//0.92 - 0.93 Converted DB to 0.93 Added speed1RM on encoder exercise
@@ -1486,9 +1682,11 @@ class Sqlite
 		creationRate ++;
 	}
 
-	public static bool Exists(string tableName, string findName)
+	public static bool Exists(bool dbconOpened, string tableName, string findName)
 	{
-		dbcon.Open();
+		if(!dbconOpened)
+			dbcon.Open();
+
 		dbcmd.CommandText = "SELECT uniqueID FROM " + tableName + 
 			" WHERE LOWER(name) == LOWER('" + findName + "')" ;
 		Log.WriteLine(dbcmd.CommandText.ToString());
@@ -1505,7 +1703,9 @@ class Sqlite
 		Log.WriteLine(string.Format("name exists = {0}", exists.ToString()));
 
 		reader.Close();
-		dbcon.Close();
+		if(!dbconOpened)
+			dbcon.Close();
+
 		return exists;
 	}
 
@@ -1821,11 +2021,11 @@ class Sqlite
 	protected internal static void convertDJInDJna()
 	{
 		//Dja exists in DB? (user defined)
-		if(Exists(Constants.JumpTypeTable, "DJa")) {
+		if(Exists(false, Constants.JumpTypeTable, "DJa")) {
 			string [] names = { "DJa-user", "DJa-user2", "DJa-user3", "DJa-user4" }; //sorry, we cannot check all the names in the world, ok, yes, i know, we can, but it's ok like this
 			bool success = false;
 			foreach(string name in names) {
-				if(!Exists(Constants.JumpTypeTable, name)) {
+				if(!Exists(false, Constants.JumpTypeTable, name)) {
 					success = true;
 					dbcmd.CommandText = "UPDATE jump SET type = '" + name + "' WHERE type == 'DJa'";
 					Log.WriteLine(dbcmd.CommandText.ToString());
@@ -1837,11 +2037,11 @@ class Sqlite
 		}
 		
 		//Djna exists in DB? (user defined)
-		if(Exists(Constants.JumpTypeTable, "DJna")) {
+		if(Exists(false, Constants.JumpTypeTable, "DJna")) {
 			string [] names = { "DJna-user", "DJna-user2", "DJna-user3", "DJna-user4" }; //sorry, we cannot check all the names in the world, ok, yes, i know, we can, but it's ok like this
 			bool success = false;
 			foreach(string name in names) {
-				if(!Exists(Constants.JumpTypeTable, name)) {
+				if(!Exists(false, Constants.JumpTypeTable, name)) {
 					success = true;
 					dbcmd.CommandText = "UPDATE jump SET type = '" + name + "' WHERE type == 'DJna'";
 					Log.WriteLine(dbcmd.CommandText.ToString());
@@ -2189,6 +2389,28 @@ Console.WriteLine("5" + tableName);
 		return myReturn;
 	}
 
+	public static void Update(bool dbconOpened, string tableName, string columnName, string searchValue, string newValue, 
+			string columnNameCondition2, string searchValueCondition2)
+	{
+		if( ! dbconOpened)
+			dbcon.Open();
+		
+		string andStr = "";
+		if(columnNameCondition2 != "" && searchValueCondition2 != "")
+			andStr = " AND " + columnNameCondition2 + " == '" + searchValueCondition2 + "'"; 
+
+		dbcmd.CommandText = "Update " + tableName +
+			" SET " + columnName + " = '" + newValue + "'" +  
+			" WHERE " + columnName + " == '" + searchValue + "'" + 
+			andStr
+			;
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		if( ! dbconOpened)
+			dbcon.Close();
+	}
+
 	public static void Delete(bool dbconOpened, string tableName, int uniqueID)
 	{
 		if( ! dbconOpened)
@@ -2203,6 +2425,20 @@ Console.WriteLine("5" + tableName);
 			dbcon.Close();
 	}
 
+	public static void DeleteFromName(bool dbconOpened, string tableName, string name)
+	{
+		if( ! dbconOpened)
+			dbcon.Open();
+
+		dbcmd.CommandText = "Delete FROM " + tableName +
+			" WHERE name == '" + name + "'";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		
+		if( ! dbconOpened)
+			dbcon.Close();
+	}
+
 
 	/* end of methods for different classes */
 	
